#!/usr/bin/env pwsh

param
(
    [Parameter(Mandatory = $true, Position = 0)]
    [string] $Baseline
)

Set-StrictMode -Version latest
$ErrorActionPreference = "Stop"

# Load support functions
. "$PSScriptRoot/../../common/include.ps1"

# Get component metadata
$component = Read-Component -Path "$PSScriptRoot/../../../component.json"

# Get launched containers images from all namespaces and select by registry
Write-Host "Getting list of deployed components..."
$podsImages = kubectl describe pods --all-namespaces | Select-String -Pattern "Image:" | Select-String -Pattern $component.registry

# Login to docker server
# Define registry server name
$pos = $component.registry.IndexOf("/")
$server = ""
if ($pos -gt 0) {
    $server = $component.registry.Substring(0, $pos)
}

# Automatically login to server
if ($env:DOCKER_USER -ne $null -and $env:DOCKER_PASS -ne $null) {
    Write-Host "Logging to $server"
    docker login $server -u $env:DOCKER_USER -p $env:DOCKER_PASS
}

foreach ($item in $podsImages) {
    [String]$podImage = $item
    # Save docker pod image and baseline image
    $dockerImage = $podImage.Substring($podImage.IndexOf("Image: ")+7).Trim()
    $dockerImageWithTag = $dockerImage
    # Remove tag from image if it exists
    if ($dockerImageWithTag.IndexOf(":") -gt 0) {
        $dockerImage = $dockerImage.Split(":")[0]
    }
    $baselineImage = $dockerImage + ":" + $Baseline

    # Pull image before tag
    Write-Host "Pulling '$dockerImageWithTag' image..."
    docker pull $dockerImageWithTag

    # Tag image with baseline tag
    docker tag $dockerImageWithTag $baselineImage

    # Push image to registry
    Write-Host "Pushing '$baselineImage' image..."
    docker push $baselineImage

    # Cleanup
    docker rmi $dockerImageWithTag --force
    docker rmi $baselineImage --force
}

Write-Host "All images from registry tagged with `"$Baseline`" successfully" -ForegroundColor Green
