#!/usr/bin/env pwsh

param
(
    [Parameter(Mandatory = $false, Position = 0)]
    [string] $Param1 = ""
)

Set-StrictMode -Version latest
$ErrorActionPreference = "Stop"

# Load support functions
. "$PSScriptRoot/../../common/include.ps1"

# Get component metadata
$component = Read-Component -Path "$PSScriptRoot/../../../component.json"

# Publish docker images
. "$PSScriptRoot/publish_docker.ps1"

# Publish by language
switch ($component.language) {
    "dart" {
        . "$PSScriptRoot/publish_dart.ps1"
    }
    "dotnet" {
        if ($Param1 -eq "") {
            . "$PSScriptRoot/publish_dotnet.ps1"
        } else {
            . "$PSScriptRoot/publish_dotnet.ps1" $Param1
        }
    }
    "java" {
        . "$PSScriptRoot/publish_java.ps1"
    }
    "node" {
        . "$PSScriptRoot/publish_node.ps1"
    }
    "python" {
        . "$PSScriptRoot/publish_python.ps1"
    }
    {($_ -eq "angular") -or ($_ -eq "vue") -or ($_ -eq "react")} {
        if ($component.type -eq "lib") {
            . "$PSScriptRoot/publish_node.ps1"
        } else {
            . "$PSScriptRoot/publish_s3.ps1"
        }
    }
    Default {
        Write-Host "Publishing for $($component.language) is not supported"
    }
}
